==> haskell-data-clist-0.1.1.0-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-clist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-clist
version: 0.1.1.0
id: data-clist-0.1.1.0-GTgxQ3fV2psCcWfrZtLEgz
key: data-clist-0.1.1.0-GTgxQ3fV2psCcWfrZtLEgz
license: BSD3
maintainer: Jeremy Huffman <jeremy@jeremyhuffman.com>, John Van Enk <vanenkj@gmail.com>
stability: experimental
homepage: https://github.com/sw17ch/data-clist
synopsis: Simple functional ring type.
description:
    Simple functional bidirectional ring type.
    Given that the ring terminiology clashes with certain
    mathematical branches, we'\''re using the term CList or
    CircularList instead.
category: Data Structures
author: John Van Enk <vanenkj@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.CircularList
abi: 06d493fb409f0eac2869405554518b02
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/data-clist-0.1.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/data-clist-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/data-clist-0.1.1.0
hs-libraries: HSdata-clist-0.1.1.0-GTgxQ3fV2psCcWfrZtLEgz
depends:
    QuickCheck-2.10.1-BUFYQzp5Pjm7JbQeTzW89l base-4.10.1.0
    deepseq-1.4.3.0
abi-depends: QuickCheck-2.10.1-BUFYQzp5Pjm7JbQeTzW89l=12616b561aced170e61d60f985fc5a23
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
haddock-interfaces: /usr/share/doc/haskell-data-clist/html/data-clist.haddock
haddock-html: /usr/share/doc/haskell-data-clist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-clist-0.1.1.0-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-clist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-clist
version: 0.1.1.0
id: data-clist-0.1.1.0-80fwGq2GOWoCmxNG1Z99T
key: data-clist-0.1.1.0-80fwGq2GOWoCmxNG1Z99T
license: BSD3
maintainer: Jeremy Huffman <jeremy@jeremyhuffman.com>, John Van Enk <vanenkj@gmail.com>
stability: experimental
homepage: https://github.com/sw17ch/data-clist
synopsis: Simple functional ring type.
description:
    Simple functional bidirectional ring type.
    Given that the ring terminiology clashes with certain
    mathematical branches, we'\''re using the term CList or
    CircularList instead.
category: Data Structures
author: John Van Enk <vanenkj@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.CircularList
abi: d9812b3d6e66c46cb7edfebcf51a4c5a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/data-clist-0.1.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/data-clist-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/data-clist-0.1.1.0
hs-libraries: HSdata-clist-0.1.1.0-80fwGq2GOWoCmxNG1Z99T
depends:
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9 base-4.10.1.0
    deepseq-1.4.3.0
abi-depends: QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=8d659ba36825a86aa37a2316500bb35b
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
haddock-interfaces: /usr/share/doc/haskell-data-clist/html/data-clist.haddock
haddock-html: /usr/share/doc/haskell-data-clist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
